# Generated by ariadne-codegen
# Source: queries.gql

from typing import Optional

from .base_model import BaseModel


class Currency(BaseModel):
    currency: Optional["CurrencyCurrency"]


class CurrencyCurrency(BaseModel):
    id: int
    name: str
    iso_code: str
    fractional_unit: Optional[str]
    number_to_basic: Optional[int]
