# Generated by ariadne-codegen
# Source: queries.gql

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class StartCalculations(BaseModel):
    start_calculations: "StartCalculationsStartCalculations" = Field(
        alias="startCalculations"
    )


class StartCalculationsStartCalculations(BaseModel):
    success: bool
    error: Optional[str]
