# Generated by ariadne-codegen
# Source: queries.gql

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class UpdateSecurityQuotes(BaseModel):
    update_security_quotes: "UpdateSecurityQuotesUpdateSecurityQuotes" = Field(
        alias="updateSecurityQuotes"
    )


class UpdateSecurityQuotesUpdateSecurityQuotes(BaseModel):
    success: bool
    error: Optional[str]
