# Generated by ariadne-codegen
# Source: queries.gql

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class UpdateSplits(BaseModel):
    update_splits: "UpdateSplitsUpdateSplits" = Field(alias="updateSplits")


class UpdateSplitsUpdateSplits(BaseModel):
    success: bool
    error: Optional[str]
