# Generated by ariadne-codegen
# Source: queries.gql

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class UpdateSecurity(BaseModel):
    update_security: "UpdateSecurityUpdateSecurity" = Field(alias="updateSecurity")


class UpdateSecurityUpdateSecurity(BaseModel):
    success: bool
    error: Optional[str]
