# Generated by ariadne-codegen
# Source: http://localhost:8042/graphql/

from enum import Enum


class SecurityType(str, Enum):
    Stock = "Stock"
    ETF = "ETF"


class DividendPeriod(str, Enum):
    Weekly = "Weekly"
    Monthly = "Monthly"
    SemiAnnual = "SemiAnnual"
    Quarterly = "Quarterly"
    Annual = "Annual"
    Other = "Other"
