# Generated by ariadne-codegen
# Source: queries.gql

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class UpdateOutstandingShares(BaseModel):
    update_outstanding_shares: "UpdateOutstandingSharesUpdateOutstandingShares" = Field(
        alias="updateOutstandingShares"
    )


class UpdateOutstandingSharesUpdateOutstandingShares(BaseModel):
    success: bool
    error: Optional[str]
