# Generated by ariadne-codegen
# Source: queries.gql

from datetime import datetime
from typing import Annotated, List, Optional

from pydantic import BeforeValidator

from .base_model import BaseModel
from .datetime_scalar import value_parser


class AllSecurityTickers(BaseModel):
    securities: List[Optional["AllSecurityTickersSecurities"]]


class AllSecurityTickersSecurities(BaseModel):
    id: int
    code: str
    last_update: Annotated[datetime, BeforeValidator(value_parser)]
    is_delisted: Optional[bool]
    exchange: "AllSecurityTickersSecuritiesExchange"


class AllSecurityTickersSecuritiesExchange(BaseModel):
    code: str
    virtual_exchange: Optional[str]
