# Generated by ariadne-codegen
# Source: queries.gql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import SecurityType


class SearchSecurity(BaseModel):
    search_security: List[Optional["SearchSecuritySearchSecurity"]] = Field(
        alias="searchSecurity"
    )


class SearchSecuritySearchSecurity(BaseModel):
    id: int
    code: str
    name: str
    type: SecurityType
