# Generated by ariadne-codegen
# Source: queries.gql

from typing import Annotated, Optional

from pydantic import BeforeValidator

from .base_model import BaseModel
from .json_scalar import value_parser


class Security(BaseModel):
    security: Optional["SecuritySecurity"]


class SecuritySecurity(BaseModel):
    name: str
    indicators: Optional[Annotated[dict, BeforeValidator(value_parser)]]
