# Generated by ariadne-codegen
# Source: queries.gql

from typing import List, Optional

from .base_model import BaseModel


class Currencies(BaseModel):
    currencies: List[Optional["CurrenciesCurrencies"]]


class CurrenciesCurrencies(BaseModel):
    id: int
    name: str
    iso_code: str
    fractional_unit: Optional[str]
    number_to_basic: Optional[int]
